# Atium

## Modules
- Data Providers
    - Calendar
    - Returns
    - Alpha
    - Factor Loadings
    - Factor Covariances
    - Idio-Vol
    - Benchmark Weights
- Strategy
    - Optimization
    - Quantile
- Optimizer
    - Objective
    - Optimizer Constraints
- Trade Generator
    - Trading Constraints
- Signal
- Signal Combinator
    - Equal
    - Inverse Volatility
    - Fama Macbeth
    - Elastic Net
- Alpha Generator
    - Grindold and Kahn
- Risk Model
    - Estimation
    - Construction
- Cost Model
    - No Cost
    - Linear Cost
- Backtester
